This is the Buildbot manual for Buildbot version ``|version|``.

Buildbot Manual
---------------

.. toctree::
   :maxdepth: 2

   introduction
   installation/index
   concepts
   configuration
   worker-transition
   customization
   new-style-steps
   cmdline
   resources
   optimization
   plugins
   deploy
